Changes
=======

0.1.1 (2015-03-30)
------------------

- Turned former `dropafile` module into a Python package. This is to
  fix installation behvior where data files are installed in different
  locations depending on install tool. See `diceware bug #1
  <https://github.com/ulif/diceware/issues/1>`_.

  The problem was revealed by `conorsch
  <https://github.com/conorsch>`_ for the `diceware
  <https://github.com/ulif/diceware>`_ package.


0.1 (2015-03-22)
----------------

- Initial release.
